==> haskell-genvalidity-1.1.1.0-73-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity
version:              1.1.1.0
visibility:           public
id:                   genvalidity-1.1.1.0-85HwjUvSKx7F2b8ubEPXOH
key:                  genvalidity-1.1.1.0-85HwjUvSKx7F2b8ubEPXOH
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  04ef8c2ffa45898dbd70db296e5365f4
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/genvalidity-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.1.0-85HwjUvSKx7F2b8ubEPXOH
depends:
    QuickCheck-2.15.0.1-5wgMd498nCWIkHPGslLJlo base-4.17.2.1
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT
    validity-0.12.1.0-2hlaJXBK7YB32tzYaJL4To

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-genvalidity-1.1.1.0-78-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-genvalidity.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity
version:              1.1.1.0
visibility:           public
id:                   genvalidity-1.1.1.0-ECLX3RA2jkf8Zuh5Fv1NvD
key:                  genvalidity-1.1.1.0-ECLX3RA2jkf8Zuh5Fv1NvD
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  f6881f0fb4e2a29a285e799efaa14131
exposed:              True
exposed-modules:      Data.GenValidity Data.GenValidity.Utils
hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/genvalidity-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/genvalidity-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/genvalidity-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity
hs-libraries:         HSgenvalidity-1.1.1.0-ECLX3RA2jkf8Zuh5Fv1NvD
depends:
    QuickCheck-2.15.0.1-Lq4ECkPzV8iDkKvRhPZIAs base-4.18.3.0
    random-1.2.1.3-GswEfj1SZ276IcAtylwQ0f
    validity-0.12.1.0-GGWrgwgukytARSsviqL9JO

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
